#
# spec file for package equalx
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           equalx
Version:        0.7.1
Release:        bp156.3.12
Summary:        Editor for writing and exporting TeX/LaTeX equations
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/TeX/Frontends
URL:            http://equalx.sourceforge.net/
Source0:        http://downloads.sourceforge.net/equalx/%{name}-%{version}.tar.gz
Source1:        %{name}.appdata.xml
# PATCH-FIX-OPENSUSE equalx-fix-desktop-file.patch badshah400@gmail.com -- Fix icon tag in desktop file and categories for compatibility with openSUSE defined ones
Patch0:         equalx-fix-desktop-file.patch
# PATCH-FIX-UPSTREAM equalx-adapt-headers-for-qt5_11.patch badshah400@opensuse.org -- Include additional header files where needed for compilation against Qt 5.11
Patch1:         equalx-adapt-headers-for-qt5_11.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  ghostscript
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkg-config
%if 0%{?suse_version} == 1500 && 0%{?sle_version} == 150100
BuildRequires:  rsvg-view
%else
BuildRequires:  rsvg-convert
%endif
%if 0%{?suse_version} > 1320
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Widgets)
%else
BuildRequires:  libqt4-devel >= 4.8.0
Requires:       libqt4-sql-sqlite
%endif
BuildRequires:  pkgconfig(exempi-2.0)
Requires:       ghostscript
Requires:       poppler-tools
Requires:       texlive-latex
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
EqualX is a helpful graphical interface to LaTeX programs. 
It gives you the power and beauty for writing TeX/LaTeX equations
in a simple to use editor.

Features included:
* Highlight find results in the Equation Preview;
* 3 modes for Refreshing the Preview
* Customise the export commands
* Professional & customisable window layout
* Equation font is computed according to desktop DPI
* Reshaping the Symbols toolbar and Templates toolbar

%prep
%setup -q
%patch0 -p1
%patch1 -p1
sed -i 's/\r$//' LICENSE README

%build
%if 0%{?suse_version} > 1320
qmake-qt5 \
%else
qmake \
%endif
DESTDIR="./bin/" QMAKE_CFLAGS="%optflags" QMAKE_CXXFLAGS="%optflags -fvisibility=hidden -fvisibility-inlines-hidden"
make %{?_smp_mflags}

%install
install -D -p bin/%{name} %{buildroot}%{_bindir}/%{name}

# GENERATE HI-RES APPLICATION ICONS
pushd resources/icons/equalx
for i in 256 512;
do
  rsvg-convert -w ${i} equalx.svg > equalx-${i}x${i}.png
done
popd

# INSTALL RESOURCES DIR
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -pr resources %{buildroot}%{_datadir}/%{name}/

# LINK ICON FILES TO HICOLOR ICON DIR
for i in 22 24 32 48 64 128 256 512;
do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps
  ln -s %{_datadir}/%{name}/resources/icons/equalx/equalx-${i}x${i}.png \
        %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/equalx.png
done
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
ln -s %{_datadir}/%{name}/resources/icons/equalx/equalx.svg \
      %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/equalx.svg

desktop-file-install resources/%{name}.desktop
# REMOVE UNUSED DESKTOP FILE
rm %{buildroot}%{_datadir}/%{name}/resources/%{name}.desktop

# INSTALL APPDATA
install -Dm0644 %{S:1} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%fdupes %{buildroot}%{_datadir}/%{name}

%if 0%{?suse_version} < 1500
%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%doc changelog README THANKS
%license LICENSE
%{_bindir}/%{name}
# OWN THE 512x512 ICON DIR AS HICOLOR THEME DOES NOT PROVIDE IT YET
%dir %{_datadir}/icons/hicolor/512x512
%dir %{_datadir}/icons/hicolor/512x512/apps
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Sat Jun  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Replace inkscape by rsvg-convert: reduces build time
  dependencies and works without GUI fixing build failures on
  openSUSE >= 1550; BuildRequires: rsvg-convert (rsvg-view for
  Leap 15.1).
- Use %%license for LICENSE file.
* Tue Jun 12 2018 badshah400@opensuse.org
- Add equalx-adapt-headers-for-qt5_11.patch: Include additional
  header files where needed for compilation against Qt 5.11
- Only run post(un) scripts for openSUSE < 1500; rpm file triggers
  take care of these for newer releases.
* Sun Oct  2 2016 badshah400@gmail.com
- Add manually created appdata file and install it.
* Sun Jul  5 2015 badshah400@gmail.com
- Use inkscape instead of convert to generate the hires icons;
  convert messes up the icon image geometry for unknown reasons.
* Thu Apr 30 2015 crrodriguez@opensuse.org
- In factory, compile against QT5.
* Wed Mar 26 2014 badshah400@gmail.com
- Update to version 0.7.1:
  + No list of changes from upstream
  + Build process changed: make install no longer does anything;
    use 'install' to manually copy generated binary to %%{_bindir}
    instead
- Use desktop file shipped in upstream tarball
  + Drop external .desktop file
  + Add equalx-fix-desktop-file.patch: Fix icon tag in shipped
    desktop file and categories for compatibility with openSUSE
    defined ones; also fix incorrect Version tag usage
- Add BuildRequires on inkscape too, required for generation of
  proper hi-res png icons from svg icon file.
* Tue Mar 25 2014 badshah400@gmail.com
- Update to version 0.7.0:
  + No list of changes from upstream
- Add explicit Requires on ghostscript and poppler-tools (these
  would have been pulled in by texlive-latex anyway, but just in
  case)
- Add Requires on libqt4-sql-sqlite: required for working history
  and bookmark features
- Do not package COPYING: file is no longer present in upstream
  tarball
- Also supply and package .desktop file and necessary icons:
  introduces BuildRequires on desktop-file-utils and
  hicolor-icon-theme (additionally, /usr/bin/convert is used to
  generate some missing hi-res icons during %%install, also needs
  ghostscript fonts)
- Package the resources dir in %%{_datadir} so that equalx can find
  the necessary resources (e.g. symbols) at runtime.
* Wed Jun 26 2013 badshah400@gmail.com
- Update to version 0.6.0:
  + Corrected transparent background bug for latex
  + Corrected square brackets
  + Corrected quadratic formula from templates
  + Equation font size defaults to size 20
  + Empty text in equation editor shows information text
  + Solved minor bugs in output of latex log
  + Implemented zoom & zoom slider
  + Preferences Dialog allows to show/hide Log
  + Latex output visible in Log Tab
  + Polished GUI
  + Now Preamble can be toggle from a button in mainwindow
  + Preferences allows to show/hide only the latex log tab
  + LatexEditor shows line numbers, same for the Preamble editor
  + Reported errors by latex output are highlighted in Equation
    editor and Preamble editor. A nice sign shows along the line
    number also
  + Fixed warnings
  + Some modifications to About Dialog
  + Fixed About Dialog links
  + Corrected "Remeber" in Preferences Dialog
  + Added class ConfigButton required for a polished GUI in the
    Modified tab "Commands" from Preferences Dialog
  + Added the GPL 3 License boilerplate to all remaining files
  + Added a check for the requirements (latex, dvipng,etc)
  + Commands paths in Preferences Dialog are now readonly - they
    can be changed only the "Change" buttons
  + Change buttons for the commands select only the specific
    executables (filters other files)
  + Added fg color, bg color, preview font size and mode in
    Preferences dialog which are saved in the settings
  + Added button "Reset Defaults" to the Preferences dialog and
    works
  + Removed Util function from defines.h and moved the Util
    functions in Util.h
  + Fixed a bug in Preferences dialog to set Font family and size
    for the equation editor
  + Corrected UpdateEquation and UpdateImage to call runCommand()
  + Added more environments: display, inline(which were before)
    and align and text. Select them from the Mainwindow and
    Preferences
  + Modified UI mainwindow and polished it for better smaller
    layout
  + Removed Latex log output and tabs from mainwindow. There is no
    need since the error parser is enough
  + Removed Parser and latex-template
  + Modified Zoom slider to show zoom level in a tooltip
  + Solved bug for find and highlight when dealing with
    transparent background color. If color is transparent than
    highlight in white
  + Fixed WidgetColorPicker.h to show real swatch transparent
    color
  + Fixed custom color selection in WidgetColorPicker
  + Modified foreground color combobox to not show transparent
    option (latex can not render transparent color)
  + Implemented a RenderEngine class to deal with the rendering
    and programs execution
  + Fixed RenderEngine
  + Added a nice preloader to show instead of the equation while
    the RenderEngine generates the files
  + Cleaned up some obsolete and unused code in MainWindow
  + Modified RenderEngine to not take care of latex exitcode. This
    is required so that we parse and display the latex errors
  + Changed preloader image with a nicer one
  + Functional preview of the generated image PNG
  + Modified RenderEngine to do check for the latex errors and
    stop if errors are found
  + Modified EquationItem to clear if no image is available.
    Equation item now shows a grab cursor (hand) if it is possible
    to drag it, normal cursor otherwise
  + Modified Mainwindow and Equation item in order to not be
    possible to drag empty equation
  + Mainwindow shows a busy cursor while the RenderEngine is
    running
- Drop equalx-fix-no-return-in-nonvoid-function.patch --
  corrected upstream
- Now requires libexempi-devel and libqt4 >= 4.8.0 for building.
* Mon Dec 12 2011 badshah400@gmail.com
- Initial package (version 0.51)
